package lt.bit.draudimas.configuration;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.security.config.annotation.authentication.builders.AuthenticationManagerBuilder;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.EnableWebSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.crypto.password.PasswordEncoder;

@Configuration
@EnableWebSecurity
public class SecurityConfiguration extends WebSecurityConfigurerAdapter {

	@Override
	protected void configure(AuthenticationManagerBuilder auth) throws Exception {
		auth
			.inMemoryAuthentication()
				.withUser("gediminas").password((new BCryptPasswordEncoder()).encode("user")).roles("user")
				.and()
				.withUser("admin").password((new BCryptPasswordEncoder()).encode("admin")).roles("user","admin");
	}
	
	
	
	@Override
	protected void configure(HttpSecurity http) throws Exception {
		
		
		http
			.authorizeRequests()
				.antMatchers("/newOwner").hasRole("admin")
				.antMatchers("/updateOwner").hasRole("admin")
				.antMatchers("/deleteOwner").hasRole("admin")
				
				.antMatchers("/css/*").permitAll()
				.antMatchers("/login*").permitAll()
				.anyRequest().authenticated()
		
		.and()
			.logout()
				.logoutUrl("/atsijungti")
				.logoutSuccessUrl("/login")
		.and()	
			.formLogin()
				.loginPage("/login")
				.failureUrl("/login-error");
		
			
	}



	@Bean
	public PasswordEncoder passwordEncoder() {
		return new BCryptPasswordEncoder();
	}
	

}
